@@ -33,6 +33,7 @@ use anyhow::{bail, Context};
 use clap::ArgMatches;
 use image::FlatSamples;
 use std::borrow::Borrow;
+use std::io::{self, Write};
 use std::sync::{mpsc, Arc, Mutex};
 use std::time::{Duration, Instant};
 use std::{env, thread};
@@ -101,7 +102,6 @@ fn main() -> Result<()> {
     let photograph = {
         let tempdir = tempdir.clone();
         let time_codes = time_codes.clone();
-        let force_natural = force_natural;
         thread::spawn(move || -> Result<()> {
             capture_thread(&rx, api, win_id, time_codes, tempdir, force_natural)
         })
@@ -109,6 +109,7 @@ fn main() -> Result<()> {
     let interact = thread::spawn(move || -> Result<()> { sub_shell_thread(&program).map(|_| ()) });
 
     clear_screen();
+    io::stdout().flush().unwrap();
     if args.get_flag("verbose") {
         println!(
             "Frame cache dir: {:?}",
@@ -120,9 +121,7 @@ fn main() -> Result<()> {
             println!("Recording window id: {}", win_id);
         }
     }
-    if args.get_flag("quiet") {
-        println!();
-    } else {
+    if !args.get_flag("quiet") {
         println!("[t-rec]: Press Ctrl+D to end recording");
     }
     thread::sleep(Duration::from_millis(1250));
